.. _restapi2:

REST API v2
***********

REST API V2 will be created on Django Rest Framework 3. Documentation is "in process".

.. .. toctree::
..    :maxdepth: 2
..    :titlesonly:

..    Objective
..    Configuration
..    Endpoint
..    Methods
..    General parameters/index
..    Request
..    Response/index
..    Resources/index
..    Errors
..    Examples
..    Useful links <Useful_links>
